package atenarium.ejb;

import java.rmi.RemoteException;
import java.util.Collection;
import java.util.LinkedList;

import javax.ejb.EJBException;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;
import javax.ejb.SessionBean;
import javax.ejb.SessionContext;

import javax.ejb.CreateException;
import javax.naming.NamingException;
import javax.xml.namespace.QName;
import javax.xml.rpc.ServiceException;

import org.apache.axis.client.Call;
import org.apache.axis.client.Service;
import org.apache.axis.encoding.ser.BeanDeserializerFactory;
import org.apache.axis.encoding.ser.BeanSerializerFactory;

import atenarium.interfaces.DepartmentLocal;
import atenarium.interfaces.DepartmentLocalHome;

import atenarium.utils.Constants;
import atenarium.utils.EJBGetter;
import atenarium.utils.report.DepartmentReportDetails;
import atenarium.utils.report.ReportDetails;

/**
 * @ejb.bean name="Atenarium"
 *           display-name="Name for Atenarium"
 *           description="Description for Atenarium"
 *           jndi-name="ejb/Atenarium"
 *           type="Stateless"
 *           view-type="remote"
 */
public class AtenariumBean implements SessionBean {
	
	private static final long serialVersionUID = -5283793756771771132L;

	DepartmentLocalHome myDepartmentLocalHome;

	public void setSessionContext(SessionContext ctx)
		throws EJBException,RemoteException {
		try {
			myDepartmentLocalHome = EJBGetter.getDepartmentLocalHome();
		} catch (NamingException e) {
			e.printStackTrace();
		}
	}

	public void ejbRemove() throws EJBException, RemoteException {}

	public void ejbActivate() throws EJBException, RemoteException {}

	public void ejbPassivate() throws EJBException, RemoteException {}

	private Collection<DepartmentReportDetails> wrapReportsDetails(ReportDetails[] aReportDetailsArray, String aDepName, String aLinkPrefix) {
		Collection<DepartmentReportDetails> toReturn = new LinkedList<DepartmentReportDetails>();
		for(ReportDetails eachReportDetails : aReportDetailsArray)
			toReturn.add(new DepartmentReportDetails(eachReportDetails,aDepName,aLinkPrefix+"/"+eachReportDetails.getId()+".pdf"));
		return toReturn;
	}
	
	
	private ReportDetails[] doCall(String aDepartmentUrl)
			throws RemoteException {

		try {
			QName methodOperationName = new QName(Constants.DEPARTMENTARIUM_WS,Constants.DEPARTMENTARIUM_WS_GET_REPORTS);
			QName methodClassDefinitionName = new QName(Constants.DEPARTMENTARIUM_WS,Constants.DEPARTMENTARIUM_WS_REPORTDETAILS);
			Class methodReportDetailsClass = ReportDetails.class;
			
			Call call = (Call) new Service().createCall();

			call.registerTypeMapping(methodReportDetailsClass,methodClassDefinitionName,
					new BeanSerializerFactory(methodReportDetailsClass,methodClassDefinitionName),
					new BeanDeserializerFactory(methodReportDetailsClass,methodClassDefinitionName));
							
			call.setTargetEndpointAddress(aDepartmentUrl);
			call.setOperationName(methodOperationName);

			Object rpcReply = call.invoke(new Object[] {});

			if (!(rpcReply instanceof ReportDetails[]))
				throw new RemoteException(Constants.BAD_RETURN_CLASS);
			return (ReportDetails[]) rpcReply;

		} catch (ServiceException e) {
			System.out.println("ServiceException");
			e.getMessage();
			e.printStackTrace();
		}

		return null;
	}
	
	/**
	 * Default create method
	 * 
	 * @throws CreateException
	 * @ejb.create-method
	 */
	public void ejbCreate() throws CreateException {
	}

	/**
	 * Business method
	 * @throws RemoteException 
	 * 
	 * @ejb.interface-method view-type = "remote"
	 */
	public DepartmentReportDetails[] getAllDepartmentReportsDetails() throws RemoteException {
		Collection<DepartmentReportDetails> methodAllDepartmentRptDet = new LinkedList<DepartmentReportDetails>();
		try {
			Collection<DepartmentLocal> methodDepartmentLclCollection = 
				myDepartmentLocalHome.findAll();
			for (DepartmentLocal eachDepartmentLocal : methodDepartmentLclCollection) {
				methodAllDepartmentRptDet.addAll(wrapReportsDetails(
						doCall(eachDepartmentLocal.getHost()+"/"+eachDepartmentLocal.getWebServiceName()),//TODO: verify
						eachDepartmentLocal.getName(),
						eachDepartmentLocal.getHost()+"/"+eachDepartmentLocal.getWebsiteName()));
			}

		} catch (FinderException e) {
			e.printStackTrace();
		}
		return methodAllDepartmentRptDet.toArray(new DepartmentReportDetails[methodAllDepartmentRptDet.size()]);
	}
	
	/**
	 * Business method
	 * @throws CreateException 
	 * @ejb.interface-method  view-type = "remote"
	 */
	public void addDepartment(String aName,String aHost,String aWebsiteName,String aWebServiceName) throws CreateException{
		try {
			DepartmentLocal methodDepartment = myDepartmentLocalHome.findByPrimaryKey(aName);
			if (methodDepartment != null)
				methodDepartment.remove();
		} catch (FinderException e) {
		} catch (EJBException e) {
			e.printStackTrace();
		} catch (RemoveException e) {
			e.printStackTrace();
		}
		myDepartmentLocalHome.create(aName,aHost,aWebsiteName,aWebServiceName);
	}
	/**
	 * Business method
	 * @throws FinderException  
	 * @ejb.interface-method  view-type = "remote"
	 */
	public void removeDepartment(java.lang.String aName) throws FinderException {
	
		DepartmentLocal depToRemove = myDepartmentLocalHome.findByPrimaryKey(aName);
		try {
			depToRemove.remove();
		} catch (EJBException e) {
			e.printStackTrace();
		} catch (RemoveException e) {
			e.printStackTrace();
		}
		
	}
}
