package atenarium.ejb;

import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.EntityBean;
import javax.ejb.EntityContext;
import javax.ejb.RemoveException;

import atenarium.utils.Constants;

/**
 * @ejb.bean name="Department"
 *           display-name="Name for Department"
 *           description="Description for Department"
 *           local-jndi-name="ejb/Department"
 *           type="CMP"
 *           schema="department"
 *           primkey-field = "name"
 *           cmp-version="2.x"
 *           view-type="local"
 *
 * @ejb.finder description = "Find All"
 * 				signature = "java.util.Collection findAll()"
 * 				query = "SELECT OBJECT(d) FROM department d"  
 */
public abstract class DepartmentBean implements EntityBean {

	public void setEntityContext(EntityContext ctx)
		throws EJBException,
		RemoteException {
	}

	public void unsetEntityContext() throws EJBException, RemoteException {
	}

	public void ejbRemove()
		throws RemoveException,
		EJBException,
		RemoteException {
	}

	public void ejbActivate() throws EJBException, RemoteException {
	}

	public void ejbPassivate() throws EJBException, RemoteException {
	}

	public void ejbLoad() throws EJBException, RemoteException {
	}

	public void ejbStore() throws EJBException, RemoteException {
	}

	private boolean areArgumentsValid(String aName,String aHost,String aWebsiteName,String aWebServiceName) {
		boolean retVal = true;
		retVal &= (aName != null) && (aName.length() > 0);
		retVal &= (aHost != null) && (aHost.length() > 0);
		retVal &= (aWebsiteName != null) && (aWebsiteName.length() > 0);
		retVal &= (aWebServiceName != null) && (aWebServiceName.length() > 0);
		return retVal;
	}

	/**
	 * Getter for CMP Field name
	 *
	 * @ejb.pk-field
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.String getName();

	/**
	 * Setter for CMP Field name
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setName(java.lang.String value);

	/**
	 * Create method
	 * @ejb.create-method  view-type = "local"
	 */
	public java.lang.String ejbCreate(String aName,String aHost,String aWebsiteName,String aWebServiceName) 
			throws javax.ejb.CreateException {
		if (!areArgumentsValid(aName, aHost,aWebsiteName, aWebServiceName))
			throw new CreateException(Constants.NOT_VALID_ARGUMENT);
		setName(aName);
		setHost(aHost);
		setWebsiteName(aWebsiteName);
		setWebServiceName(aWebServiceName);
		return null;//TODO:please improve
	}
	/**
	 * Post Create method
	 */
	public void ejbPostCreate(String aName,String aHost,String aWebsiteName,String aWebServiceName)
		throws javax.ejb.CreateException {
	}
	/**
	 * Getter for CMP Field host
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.String getHost();

	/**
	 * Setter for CMP Field host
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setHost(java.lang.String value);

	/**
	 * Getter for CMP Field websiteName
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.String getWebsiteName();

	/**
	 * Setter for CMP Field websiteName
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setWebsiteName(java.lang.String value);

	/**
	 * Getter for CMP Field webServiceName
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.String getWebServiceName();

	/**
	 * Setter for CMP Field webServiceName
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setWebServiceName(java.lang.String value);

}
