package atenarium.web.beans;

import java.io.Serializable;
import java.rmi.RemoteException;
import java.util.LinkedList;
import java.util.List;

import atenarium.interfaces.Atenarium;
import atenarium.interfaces.AtenariumHome;
import atenarium.utils.EJBGetter;
import atenarium.utils.report.DepartmentReportDetails;
import atenarium.web.beans.filters.AuthorFilterBean;
import atenarium.web.beans.filters.FilterBean;
import atenarium.web.beans.filters.KeywordsFilterBean;
import atenarium.web.beans.filters.TitleFilterBean;


public class VisitJavaBean implements Serializable {
	
	private static final long serialVersionUID = 8699140861828836243L;
	
	private Atenarium myAtenarium;
	private DepartmentReportDetails[] myDepartmentReportDetailsArray;
	private List<FilterBean> myFiltersList;
	
	public VisitJavaBean() {
		AtenariumHome home;
		try {
			home = EJBGetter.getAtenariumHome();
			myAtenarium = home.create();
			updateDepReportDetails();
			initializeFilters();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	private void updateDepReportDetails() throws RemoteException {
		myDepartmentReportDetailsArray = myAtenarium.getAllDepartmentReportsDetails();
	}
	
	private void initializeFilters() {
		myFiltersList = new LinkedList<FilterBean>();
		myFiltersList.add(
				new TitleFilterBean(DepartmentReportDetails.getTitles(myDepartmentReportDetailsArray)));
		myFiltersList.add(
				new AuthorFilterBean(DepartmentReportDetails.getAuthors(myDepartmentReportDetailsArray)));
		myFiltersList.add(
				new KeywordsFilterBean(DepartmentReportDetails.getKeywords(myDepartmentReportDetailsArray)));
	}
	
	public Atenarium getAtenarium() { return myAtenarium; }
	
	public DepartmentReportDetails[] getDepartmentsReportDetails() throws RemoteException {
		DepartmentReportDetails[] methodDepRepDetArray = myDepartmentReportDetailsArray;
		for(FilterBean eachFilter : myFiltersList)
			methodDepRepDetArray = eachFilter.doFiltering(methodDepRepDetArray);
		return methodDepRepDetArray;
	}
	
	public List<FilterBean> getFilters() { return myFiltersList; }
	
}
	
