package departmentarium.ejb;

import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.EntityBean;
import javax.ejb.EntityContext;
import javax.ejb.RemoveException;

import departmentarium.utils.Constants;

/**
 * @ejb.bean name="Configuration"
 *           display-name="Name for Configuration"
 *           description="Description for Configuration"
 *           local-jndi-name="ejb/Configuration"
 *           primkey-field="primaryKey"
 *           type="CMP"
 *           schema="configuration"
 *           cmp-version="2.x"
 *           view-type="local"
 *           
 */
public abstract class ConfigurationBean implements EntityBean {

	public void setEntityContext(EntityContext ctx)
		throws EJBException,
		RemoteException {
	}

	public void unsetEntityContext() throws EJBException, RemoteException {
	}

	public void ejbRemove()
		throws RemoveException,
		EJBException,
		RemoteException {
	}

	public void ejbActivate() throws EJBException, RemoteException {
	}

	public void ejbPassivate() throws EJBException, RemoteException {
	}

	public void ejbLoad() throws EJBException, RemoteException {
	}

	public void ejbStore() throws EJBException, RemoteException {
	}

	private boolean areArgumentsValid(
		String aName,
		String aHost,
		String aWebsiteName,
		String aWebServiceName,
		String aAtenariumUrl,
		String aPrefix) {
		boolean retVal = true;
		retVal &= (aName != null) && (aName.length() > 0);
		retVal &= (aHost != null) && (aHost.length() > 0);
		retVal &= (aWebsiteName != null) && (aWebsiteName.length() > 0);
		retVal &= (aWebServiceName != null) && (aWebServiceName.length() > 0);
		retVal &= (aAtenariumUrl != null) && (aAtenariumUrl.length() > 0); //TODO: url REAL check
		retVal &= (aPrefix != null) && (aPrefix.length() > 0);
		return retVal;
	}

	/**
	 * Getter for CMP Field prefix
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.String getPrefix();

	/**
	 * Setter for CMP Field prefix
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setPrefix(java.lang.String value);

	/**
	 * Getter for CMP Field atenariumUrl
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.String getAtenariumUrl();

	/**
	 * Setter for CMP Field atenariumUrl
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setAtenariumUrl(java.lang.String value);

	/**
	 * Create method
	 * @ejb.create-method  view-type = "local"
	 */
	public java.lang.String ejbCreate(
		String aName,
		String aHost,
		String aWebsiteName,
		String aWebServiceName,
		String aAtenariumUrl,
		String aPrefix) throws javax.ejb.CreateException {

		if (!areArgumentsValid(
			aName,
			aHost,
			aWebsiteName,
			aWebServiceName,
			aAtenariumUrl,
			aPrefix))
			throw new CreateException(Constants.BAD_DEP_CONFIGURATION_ARGUMENTS);
		setPrimaryKey(Constants.CONFIGURATION_PRIMARY_KEY);
		setName(aName);
		setHost(aHost);
		setWebsiteName(aWebsiteName);
		setWebServiceName(aWebServiceName);
		setAtenariumUrl(aAtenariumUrl);
		setPrefix(aPrefix);
		setLastId(Constants.STARTING_ID);
		return null;
	}
	/**
	 * Post Create method
	 */
	public void ejbPostCreate(
		String aName,
		String aHost,
		String aWebsiteName,
		String aWebServiceName,
		String aAtenariumUrl,
		String aPrefix) throws javax.ejb.CreateException {
	}
	/**
	 * Getter for CMP Field host
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.String getHost();

	/**
	 * Setter for CMP Field host
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setHost(java.lang.String value);

	/**
	 * Getter for CMP Field websiteName
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.String getWebsiteName();

	/**
	 * Setter for CMP Field websiteName
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setWebsiteName(java.lang.String value);

	/**
	 * Getter for CMP Field webServiceName
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.String getWebServiceName();

	/**
	 * Setter for CMP Field webServiceName
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setWebServiceName(java.lang.String value);

	/**
	 * Getter for CMP Field pk
	 *
	 * @ejb.pk-field
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract String getPrimaryKey();

	/**
	 * Setter for CMP Field pk
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setPrimaryKey(String value);

	/**
	 * Getter for CMP Field name
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.String getName();

	/**
	 * Setter for CMP Field name
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setName(java.lang.String value);

	/**
	 * Getter for CMP Field lastId
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract int getLastId();

	/**
	 * Setter for CMP Field lastId
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setLastId(int value);

	/**
	 * Business method
	 * @ejb.interface-method  view-type = "local"
	 */
	public synchronized String provideReportId() {
		int currentId = getLastId();
		String toReturnId = getPrefix() + Constants.REPORT_ID_PREFIX_NUMBER_SEPARATOR + currentId;
		setLastId(currentId+1);
		return toReturnId;
	}
}
