package departmentarium.ejb;

import java.rmi.RemoteException;

import departmentarium.interfaces.UserLocal;
import departmentarium.utils.*;
import departmentarium.utils.exceptions.ReportException;
import departmentarium.utils.wrappers.ReportDetails;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.EntityBean;
import javax.ejb.EntityContext;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;

/**
 * @ejb.bean name="Report"
 *           display-name="Repor Entity tBean"
 *           local-jndi-name="ejb/Report"
 *           primkey-field="id"
 *           type="CMP"
 *           schema="report"
 *           cmp-version="2.x"
 *           view-type="local"
 *           
 * @ejb.finder description = "Find All"
 * 				signature = "java.util.Collection findAll()"
 * 				query = "SELECT OBJECT(r) FROM report r"        
 */
public abstract class ReportBean implements EntityBean {

	/**
	 * Create method
	 * @ejb.create-method  view-type = "local"
	 */
	public String ejbCreate(
		ReportDetails aReportDetails, byte[] aFile,
		UserLocal aUserLocal) throws CreateException {
		if (!isUserAuthor(aReportDetails,aUserLocal))
			throw new CreateException(Constants.NOT_SAME_AUTHOR);
		else if (isReportAlreadyPresent(aReportDetails))
			throw new CreateException(Constants.DUPLICATE_REPORT);
		else {
			setFields(aReportDetails, aFile);
			return null; }
	}

	/**
	 * Post Create method
	 */
	public void ejbPostCreate(ReportDetails aReportDetails, byte[] aFile, UserLocal aUserLocal)
		throws CreateException {
		setUser(aUserLocal);
	}

	/**
	 * Business method
	 * @ejb.interface-method  view-type = "local"
	 */
	public void update(ReportDetails aReportDetails, byte[] aFile) throws ReportException {
		if (!isUpdatableReport(aReportDetails))
			throw new ReportException(Constants.WRONG_REPORT);
		else
			updateFields(aReportDetails, aFile);
	}

	public void setEntityContext(EntityContext ctx)
		throws EJBException,
		RemoteException {
	}

	public void unsetEntityContext() throws EJBException, RemoteException {
	}

	private void setFields(ReportDetails aReportDetails, byte[] aFile) {
		setId(aReportDetails.getId().toString());
		setTitle(aReportDetails.getTitle());
		setDate(aReportDetails.getDate());
		setKeywords(aReportDetails.getKeywords());
		setFile(aFile);
		setIsACollection(aReportDetails.isACollection());
	}
	
	private void updateFields(ReportDetails aReportDetails, byte[] aFile) {
		setTitle(aReportDetails.getTitle());
		setDate(aReportDetails.getDate());
		setKeywords(aReportDetails.getKeywords());
		setFile(aFile);
	}

	private boolean isUpdatableReport(ReportDetails aReportDetails) {
		boolean retValue = true;
		retValue &= (getId().compareTo(aReportDetails.getId().toString()) == 0);
		retValue &= (aReportDetails.getAuthor().equals(getUser().getLogin()));
		return retValue;
	}

	private boolean isReportAlreadyPresent(ReportDetails aReportDetails) {
		try {
			if (ejbSelectCountId(aReportDetails.getId().toString()).size() > 0)
				return true;
		} catch (FinderException e) {
			e.printStackTrace();
		}
		return false;
	}
	
	private boolean isUserAuthor(ReportDetails aReportDetails, UserLocal aUser) {
		return (aReportDetails.getAuthor().compareTo(aUser.getLogin()) == 0);
	}

	public void ejbRemove()
		throws RemoveException,
		EJBException,
		RemoteException {
	}

	public void ejbActivate() throws EJBException, RemoteException {
	}

	public void ejbPassivate() throws EJBException, RemoteException {
	}

	public void ejbLoad() throws EJBException, RemoteException {
	}

	public void ejbStore() throws EJBException, RemoteException {
	}

	/**
	 * Getter for CMP Field id
	 *
	 * @ejb.pk-field
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract String getId();

	/**
	 * Setter for CMP Field id
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setId(String value);

	/**
	 * Getter for CMP Field title
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.String getTitle();

	/**
	 * Setter for CMP Field title
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setTitle(java.lang.String value);

	/**
	 * Getter for CMP Field date
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.String getDate();

	/**
	 * Setter for CMP Field date
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setDate(java.lang.String value);

	/**
	 * Getter for CMP Field file
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract byte[] getFile();

	/**
	 * Setter for CMP Field file
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setFile(byte[] value);

	/**
	 * Getter for CMP Field isACollection
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.Boolean getIsACollection();

	/**
	 * Setter for CMP Field isACollection
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setIsACollection(java.lang.Boolean value);

	/**
	 * Getter for CMP Field keywords
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.String getKeywords();

	/**
	 * Setter for CMP Field keywords
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setKeywords(java.lang.String value);
	
	/**
	 * Getter for CMR Relationship
	 *
	 * @ejb.interface-method   view-type="local"
	 * @ejb.relation           name = "User-Report"
	 *                         role-name = "report-belongs-to-user"
	 *                         target-multiple = "yes"
	 *                         
	 * @jboss.relation 
	 * 						fk-column = "userLogin"
	 * 						related-pk-field = "login"
	 */
	public abstract departmentarium.interfaces.UserLocal getUser();

	/**
	 * Setter for CMR Relationship
	 *
	 *@ejb.interface-method   view-type="local"
	 */
	public abstract void setUser(departmentarium.interfaces.UserLocal value);

	/**
	 * @ejb.select  query = "SELECT OBJECT(r) FROM report r WHERE r.id = ?1"
	 */
	public abstract java.util.Collection ejbSelectCountId(String aReportIdString)
		throws javax.ejb.FinderException;

}
