package departmentarium.ejb;

import departmentarium.utils.Constants;

import java.rmi.RemoteException;

import javax.ejb.CreateException;
import javax.ejb.EJBException;
import javax.ejb.EntityBean;
import javax.ejb.EntityContext;
import javax.ejb.FinderException;
import javax.ejb.RemoveException;

/**
 * @ejb.bean name="User"
 *           display-name="UserBean"
 *           local-jndi-name="ejb/User"
 *           primkey-field="login"
 *           type="CMP"
 *           schema = "user"
 *           cmp-version="2.x"
 *           view-type="local"
 *           
 * @ejb.finder description = "Find All"
 * 				signature = "java.util.Collection findAll()"
 * 				query = "SELECT OBJECT(u) FROM user u" 
 *           
 * @ejb.finder 
 * 			description = "find by Login and Password"
 * 			signature = "java.util.Collection findByLoginAndPassword(java.lang.String aLogin,
 * 									java.lang.String aPassword)"
 * 			query = "SELECT OBJECT(u) FROM user u WHERE
 * 						u.login = ?1 AND
 * 						u.password = ?2"
 * 				
 */
public abstract class UserBean implements EntityBean {

	/**
	 * Create method
	 * @ejb.create-method  view-type = "local"
	 */
	public String ejbCreate(String aLogin, String aPassword)
		throws CreateException {
		if (isThereLogin(aLogin))
			throw new CreateException(Constants.CANNOT_CREATE_LOGIN);
		setLogin(aLogin);
		setPassword(cipherPassword(aPassword));
		setIsAdmin(new Boolean(false));
		return null;//TODO: should return the primary key
	}

	/**
	 * Post Create method
	 */
	public void ejbPostCreate(String aLogin, String aPassword) {
	}

	/**
	 * Create method
	 * @ejb.create-method  view-type = "local"
	 */
	public java.lang.String ejbCreateAdmin(
		java.lang.String aLogin,
		java.lang.String aPassword) throws javax.ejb.CreateException {
		if (isThereAdmin())
			throw new CreateException(Constants.CANNOT_CREATE_ADMIN);
		else {
			setLogin(aLogin);
			setPassword(cipherPassword(aPassword));
			setIsAdmin(new Boolean(true));
			return null; //TODO: should return the primary key
		}
	}
	/**
	 * Post Create method
	 */
	public void ejbPostCreateAdmin(
		java.lang.String aLogin,
		java.lang.String aPassword) throws javax.ejb.CreateException {}

	private String cipherPassword(String aPassword) {
		//TODO: should chiper the provided password
		return aPassword;
	}
	
	private boolean isThereAdmin() {
		try {
			return ejbSelectCountAdmin().size()>0;
		} catch (FinderException e) {
			e.printStackTrace(); }
		return false;
	}
	
	private boolean isThereLogin(String aLogin) {
		try {
			return ejbSelectCountLogin(aLogin).size()>0;
		} catch (FinderException e) {
			e.printStackTrace(); }
		return false;
	}

	public void setEntityContext(EntityContext ctx)
		throws EJBException,
		RemoteException {
	}

	public void unsetEntityContext() throws EJBException, RemoteException {
	}

	public void ejbRemove()
		throws RemoveException,
		EJBException,
		RemoteException {
	}

	public void ejbActivate() throws EJBException, RemoteException {
	}

	public void ejbPassivate() throws EJBException, RemoteException {
	}

	public void ejbLoad() throws EJBException, RemoteException {
	}

	public void ejbStore() throws EJBException, RemoteException {
	}

	/**
	 * Getter for CMP Field login
	 *
	 * @ejb.pk-field
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.String getLogin();

	/**
	 * Setter for CMP Field login
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setLogin(java.lang.String value);

	/**
	 * Getter for CMP Field password
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.String getPassword();
	
	/**
	 * Getter for CMP Field password
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract String getObtainedId();

	/**
	 * Setter for CMP Field password
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setPassword(java.lang.String value);
	
	/**
	 * Setter for CMP Field password
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setObtainedId(String value);

	/**
	 * Getter for CMP Field isAdmin
	 *
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract java.lang.Boolean getIsAdmin();

	/**
	 * Setter for CMP Field isAdmin
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	public abstract void setIsAdmin(java.lang.Boolean value);

	/**
	 * Getter for CMR Relationship
	 *
	 * @ejb.interface-method   view-type="local"
	 * @ejb.relation           name = "User-Report"
	 *                         role-name = "user-has-reports"
	 *                         target-multiple = "no"
	 *                         
	 */
	 public abstract java.util.Collection getReports();

	 /**
	 * Setter for CMR Relationship
	 *
	 * @ejb.interface-method   view-type="local"
	 */
	 public abstract void setReports(java.util.Collection value);
	
	/**
	 * @ejb.select  query = "SELECT OBJECT(u) FROM user u WHERE u.login = ?1"
	 */
	public abstract java.util.Collection ejbSelectCountLogin(String login) 
		throws javax.ejb.FinderException;
	
	/**
	 * Select method
	 * @ejb.select  query = "SELECT OBJECT(u) FROM user u WHERE u.isAdmin = true"
	 */
	public abstract java.util.Collection ejbSelectCountAdmin()
		throws javax.ejb.FinderException;
}
