package departmentarium.utils.pdf;

import java.util.HashMap;
import java.util.Map;

import departmentarium.utils.Constants;
import departmentarium.utils.wrappers.ReportDetails;

public class MetadataDetails {
	
	private String myId;
	private String myTitle;
	private String myAuthor;
	private String myKeywords;
	private String myDate;
	private boolean isACollection;
	
	public MetadataDetails(String aId, String aAuthor, String aTitle, String aKeywords, String aDate, boolean ifCollection) {
		myId = aId;
		myAuthor = aAuthor;
		myTitle = aTitle;
		myKeywords = aKeywords;
		myDate = aDate;
		isACollection = ifCollection;
	}
	
	public MetadataDetails(Map mappedDetails) throws MetadataException {
		if (!validMetadata(mappedDetails))
			throw new MetadataException(Constants.METADATA_MISSING_FIELD);
		else
			myId = (String)mappedDetails.get(Constants.ID);
			myAuthor = (String)mappedDetails.get(Constants.AUTHOR);
			myTitle = (String)mappedDetails.get(Constants.TITLE);
			myKeywords = (String)mappedDetails.get(Constants.KEYWORDS);
			myDate = (String)mappedDetails.get(Constants.DATE);
			isACollection = ((String)mappedDetails.get(Constants.ISCOLLECTION) == String.valueOf(true));
	}
	
	public String getId() { return myId; }
	public String getTitle() { return myTitle; }
	public String getAuthor() { return myAuthor; }
	public String getKeywords() { return myKeywords; }
	public String getDate() { return myDate; }
	public boolean isACollection() { return isACollection; }
	
	public boolean validMetadata(Map mappedDetails) {
		if (!mappedDetails.containsKey(Constants.ID) ||
				!mappedDetails.containsKey(Constants.AUTHOR) ||	
				!mappedDetails.containsKey(Constants.TITLE) ||
				!mappedDetails.containsKey(Constants.KEYWORDS) ||
				!mappedDetails.containsKey(Constants.DATE) ||
				!mappedDetails.containsKey(Constants.ISCOLLECTION))
			return false;
		else
			return true;
	}
	
	public HashMap getDetailsMap() {
		HashMap methodMap = new HashMap();
		methodMap.put(Constants.ID,getId());
		methodMap.put(Constants.AUTHOR,getAuthor());
		methodMap.put(Constants.TITLE,getTitle());
		methodMap.put(Constants.KEYWORDS,getKeywords());
		methodMap.put(Constants.DATE,getDate());
		methodMap.put(Constants.ISCOLLECTION,String.valueOf(isACollection));
		return methodMap;
	}
	
	public String toString() {
		String retValue = new String();
		retValue += (Constants.ID + " : " + getId() + "\n");
		retValue += (Constants.AUTHOR + " : " + getAuthor() + "\n");
		retValue += (Constants.TITLE + " : " + getTitle() + "\n");
		retValue += (Constants.KEYWORDS + " : " + getKeywords() + "\n");
		retValue += (Constants.DATE + " : " + getDate() + "\n");
		retValue += (Constants.ISCOLLECTION + " : " + String.valueOf(isACollection) + "\n");
		return retValue;
	}
	
	public static ReportDetails MetadataToReportDetails(MetadataDetails aMetadataDetails) {
		return new ReportDetails(aMetadataDetails.getId(),
								 aMetadataDetails.getTitle(),
								 aMetadataDetails.getDate(),
								 aMetadataDetails.getAuthor(),
								 aMetadataDetails.getKeywords(),
								 aMetadataDetails.isACollection());
	}
	
	public static MetadataDetails ReportToMetadataDetails(ReportDetails aReportDetails) {
		return new MetadataDetails(aReportDetails.getId(),
								   aReportDetails.getAuthor(),
								   aReportDetails.getTitle(),
								   aReportDetails.getKeywords(),
								   aReportDetails.getDate(),
								   aReportDetails.isACollection());
	}
}
