package departmentarium.web;

import java.io.IOException;
import java.io.OutputStream;
import javax.ejb.FinderException;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import departmentarium.interfaces.Departmentarium;
import departmentarium.interfaces.DepartmentariumHome;
import departmentarium.utils.EJBGetter;

/**
 * @web.servlet
 * 		name = "Report Servlet"
 * 
 * @web.servlet-mapping
 * 		url-pattern = "*.pdf"
 * 
 * @web.ejb-ref
 * 			name="ejb/Departmentarium"
 * 			type="Session"
 * 			home="departmentarium.interfaces.DepartmentariumHome"
 * 			remote="departmentarium.interfaces.Departmentarium"
 * 			description="Reference to the Departmentarium EJB"
 * 
 * 
 * @jboss.ejb-ref-jndi
 * 			ref-name = "ejb/Departmentarium"
 * 			jndi-name = "ejb/Departmentarium"
 */
public class ReportReturnServlet extends HttpServlet {

	private static final long serialVersionUID = 1L;

	private String parseRequestUrl(String aRequestUri, String aContextPath) {
		String toReturn = aRequestUri.replaceAll(aContextPath+"/","");
		toReturn = toReturn.replaceAll(".pdf","");
		return toReturn;
	}
	
	protected void doGet(HttpServletRequest req, HttpServletResponse resp) throws ServletException, IOException {
		
		DepartmentariumHome home;
		try {
			home = EJBGetter.getDepartmentariumHome();
			Departmentarium myDepartmentarium = home.create();
			
			String requestedReportId = parseRequestUrl(req.getRequestURI(),req.getContextPath()); 
			
			try {
				byte[] reportToReturn = myDepartmentarium.getReport(requestedReportId);
				resp.setContentType("application/pdf");
				
				OutputStream os = resp.getOutputStream();
				os.write(reportToReturn);
				os.flush();
				os.close();
				
			} catch (FinderException e) {
				resp.sendError(404);
				e.printStackTrace();
			}
			
		} catch (Exception e) {
			e.printStackTrace();
		}  
	}

}
