package departmentarium.web.beans;

import java.io.Serializable;
import java.util.LinkedList;
import java.util.List;

import departmentarium.interfaces.Departmentarium;
import departmentarium.interfaces.DepartmentariumHome;
import departmentarium.utils.*;
import departmentarium.web.beans.actions.*;

public class UserJavaBean implements Serializable {
	
	private static final long serialVersionUID = -2568450654745666646L;
	private String myUsername;
	private String myPassword;
	private String myUserKind;
	private boolean isLoggedIn = false;
	private ActionBean mySelectedAction = null;
	
	private List<ActionBean> myActions = new LinkedList<ActionBean>();
	
	private Departmentarium myDepartmentarium;
	
	public UserJavaBean() {
		DepartmentariumHome home;
		try {
			home = EJBGetter.getDepartmentariumHome();
			myDepartmentarium = home.create();
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
	
	public Departmentarium getDepartmentarium() { return myDepartmentarium; }
	
	public void setSelectedAction(ActionBean aActionBean) {
		for (ActionBean eachAction : myActions)
			eachAction.doUnselection();
		mySelectedAction = aActionBean;
	}
	
	public ActionBean getSelectedAction() { return mySelectedAction; }
	
	public List getActions() { return myActions; }
	
	public boolean isLoggedIn() { return isLoggedIn; }
	
	public String getUserKind() { return myUserKind; }
	
	
	public String getLoggingOperation() {
		if (isLoggedIn)
			return "logout";
		else
			return "login";
	}
	
	public String getPassword() { return myPassword; }
	
	public void setPassword(String aPassword) { myPassword = aPassword; }
	
	public String getUsername() { return myUsername; }
	
	public void setUsername(String aUsername) { myUsername = aUsername; }
	
	private void setInfos() {
		isLoggedIn = true;
		myActions.clear();
		if (myUserKind.equals(Constants.ADMIN)) {
			myActions.add(new AddUserActionBean(this));
			myActions.add(new ViewUsersActionBean(this));
			myActions.add(new SetupDepartmentariumActionBean(this));
		}
		else if (myUserKind.equals(Constants.USER)) {
			myActions.add(new AddReportActionBean(this));
			myActions.add(new AddReportWzrdActionBean(this));
			myActions.add(new ViewReportActionBean(this));
		}
	}
	
	private void resetInfos() {
		setUsername("");
		setPassword("");
		myUserKind = "";
		myActions.clear();
		mySelectedAction = null;
		isLoggedIn = false;
	}
	
	public String doLogin() {
		try {
			myUserKind = myDepartmentarium.getUserKind(getUsername(),getPassword());
			
			if (myUserKind.equals(Constants.NOT_VALID_USER))
				resetInfos(); 
			else 
				setInfos(); 
			return myUserKind;
			
		} catch (Exception e) {
			resetInfos();
			return null;
		}
	}
	
	public String doLogout() {
		resetInfos();
		return "logout";
	}
	

}
