package departmentarium.web.beans.actions;

import java.io.IOException;
import java.rmi.RemoteException;

import javax.ejb.FinderException;

import org.apache.myfaces.custom.fileupload.UploadedFile;

import departmentarium.utils.Constants;
import departmentarium.utils.exceptions.ReportException;
import departmentarium.utils.pdf.MetadataDetails;
import departmentarium.utils.pdf.MetadataException;
import departmentarium.utils.pdf.PDFManager;
import departmentarium.utils.wrappers.ReportDetails;
import departmentarium.web.beans.UserJavaBean;

public class AddReportActionBean implements ActionBean {

	private String myReportId;
	private boolean isReportACollection = false;
	private UserJavaBean myUserJavaBean;
	private boolean isSelected = false;
	private UploadedFile myFile = null;
	private String myError;
	
	public AddReportActionBean(UserJavaBean aUserJavaBean) {
		myUserJavaBean = aUserJavaBean;
		try {
			initializeReportDetails();
		} catch (Exception e) {
			e.printStackTrace();} 
	}
	
	public String getError() { return myError; }
	public String getReportId() { return myReportId; }
	public boolean isReportACollection() { return isReportACollection; }
    public UploadedFile getMyFile() { return myFile; }

    public void setMyFile(UploadedFile aFile) { myFile = aFile; }
	public void setReportId(String aString) { myReportId = aString; }
	public void setReportACollection(boolean aBoolean) { isReportACollection = aBoolean; }
	public void setError(Exception anException) { myError = anException.getMessage(); }

	private void initializeReportDetails() throws RemoteException, FinderException, ReportException {
		String currentUsername = myUserJavaBean.getUsername();
		String currentPassword = myUserJavaBean.getPassword();
		setReportId(myUserJavaBean.getDepartmentarium().getId(currentUsername,currentPassword));
		myFile = null;
	}
	
	private void reset() throws RemoteException, FinderException, ReportException {
		isSelected = false;
		initializeReportDetails();
	}
	
	public String getName() { return Constants.ACTION_ADD_REPORT; }

	public String getId() { return Constants.ID_ACTION_ADD_REPORT; }

	public boolean isSelected() { return isSelected; }

	public String doSelection() {
		isSelected = true;
		myUserJavaBean.setSelectedAction(this);
		return getId();
	}

	public String doUnselection() {
		try {
			reset();
			return getId();
		} catch (Exception e) {
			e.printStackTrace(); 
			return null; }
	}
	
	private ReportDetails generateReportDetails(UploadedFile myFile) throws IOException, MetadataException {
			MetadataDetails methodMetadataDetails = PDFManager.getMetadata(myFile.getBytes());
			return MetadataDetails.MetadataToReportDetails(methodMetadataDetails);
	}
	
	public String doAction() {
		String currentUsername = myUserJavaBean.getUsername();
		String currentPassword = myUserJavaBean.getPassword();
		try {
			ReportDetails methodReportDetails = generateReportDetails(myFile);
			myUserJavaBean.getDepartmentarium().addReport(currentUsername,currentPassword,methodReportDetails,myFile.getBytes());
			reset();
		} catch (Exception e) {
			setError(e);
			return Constants.ACTION_NOT_DONE;
		}
		return Constants.ACTION_DONE;
	}
	
}
