package departmentarium.web.beans.actions;

import java.io.IOException;
import java.rmi.RemoteException;
import javax.ejb.FinderException;
import org.apache.myfaces.custom.fileupload.UploadedFile;

import com.lowagie.text.DocumentException;

import departmentarium.utils.Constants;
import departmentarium.utils.exceptions.ReportException;
import departmentarium.utils.pdf.MetadataDetails;
import departmentarium.utils.pdf.MetadataException;
import departmentarium.utils.pdf.PDFManager;
import departmentarium.utils.wrappers.ReportDetails;
import departmentarium.web.beans.TimeBean;
import departmentarium.web.beans.UserJavaBean;

public class AddReportWzrdActionBean implements ActionBean {
	
	private ReportDetails myReportDetails;
	private UserJavaBean myUserJavaBean;
	private boolean isSelected = false;
	private UploadedFile myFile;
	private TimeBean myTimeBean = new TimeBean();
	private String myError;
	
	public AddReportWzrdActionBean(UserJavaBean aUserJavaBean) {
		myUserJavaBean = aUserJavaBean;
		try {
			initializeReportDetails();
		} catch (Exception e) {
			e.printStackTrace();} 
	}
	
	
	public String getReportId() { return myReportDetails.getId(); }
	public String getReportTitle() { return myReportDetails.getTitle(); }
	public String getReportAuthor() { return myReportDetails.getAuthor(); }
	public String getReportKeywords() { return myReportDetails.getKeywords(); }
	public String getReportDate() { return (myReportDetails.getDate()); }
	public boolean isReportACollection() { return (myReportDetails.isACollection()); }
    public UploadedFile getMyFile() { return myFile; }

    public void setMyFile(UploadedFile aFile) { myFile = aFile; }
	public void setReportId(String aString) { myReportDetails.setId(aString); }
	public void setReportTitle(String aString) { myReportDetails.setTitle(aString); }
	public void setReportAuthor(String aString) { myReportDetails.setAuthor(aString); }
	public void setReportKeywords(String aString) { myReportDetails.setKeywords(aString); }
	public void setReportDate(String aString) { myReportDetails.setDate(aString); }
	public void setReportACollection(boolean aBoolean) { myReportDetails.setIsACollection(aBoolean); }
	
	public String getError() { return myError; }
	public void setError(Exception anException) { myError = anException.getMessage(); }

	private void initializeReportDetails() throws RemoteException, FinderException, ReportException {
		String currentUsername = myUserJavaBean.getUsername();
		String currentPassword = myUserJavaBean.getPassword();
		String methodId = myUserJavaBean.getDepartmentarium().getId(currentUsername,currentPassword);
		String currentDate = myTimeBean.getDate();
		myReportDetails = new ReportDetails(methodId,"",currentDate,currentUsername,"",false);
		myFile = null;
	}
	
	private void reset() throws RemoteException, FinderException, ReportException {
		isSelected = false;
		initializeReportDetails();
	}
	
	public String getName() { return Constants.ACTION_REPORT_WIZARD; }

	public String getId() { return Constants.ID_ACTION_REPORT_WIZARD; }

	public boolean isSelected() { return isSelected; }

	public String doSelection() {
		isSelected = true;
		myUserJavaBean.setSelectedAction(this);
		return getId();
	}

	public String doUnselection() {
		try {
			reset();
			return getId();
		} catch (Exception e) {
			e.printStackTrace(); 
			return null; }
	}
	
	private byte[] generateFilledPdf() throws IOException, DocumentException, MetadataException {
		MetadataDetails methodMetadataDetails = MetadataDetails.ReportToMetadataDetails(myReportDetails);
		return PDFManager.createFromMetadataAndDoc(methodMetadataDetails,myFile.getBytes());
	}
	
	public String doAction() {
		String currentUsername = myUserJavaBean.getUsername();
		String currentPassword = myUserJavaBean.getPassword();
		try {
			byte[] currentFilledPDF = generateFilledPdf();
			myUserJavaBean.getDepartmentarium().addReport(currentUsername,currentPassword,myReportDetails,currentFilledPDF);
			reset();
		} catch (Exception e) {
			setError(e);
			return Constants.ACTION_NOT_DONE;
		}
		return Constants.ACTION_DONE;
	}
}
