package departmentarium.web.beans.actions;

import departmentarium.utils.Constants;
import departmentarium.utils.wrappers.ConfigurationPojo;

import departmentarium.web.beans.UserJavaBean;

public class SetupDepartmentariumActionBean implements ActionBean {

	private UserJavaBean myUserJavaBean;
	
	ConfigurationPojo myConfigurationPojo;	
	
	private boolean isSelected = false;

	private String myError;
	
	public SetupDepartmentariumActionBean(UserJavaBean aUserJavaBean) {
		myUserJavaBean = aUserJavaBean;
		setFromPersistent();
	}
	
	private void setFromPersistent() {
		ConfigurationPojo methodConfPojo;
		try {
			methodConfPojo = myUserJavaBean.getDepartmentarium().getConfiguration();
			if (methodConfPojo == null)
				setParametersEmpty();
			else
				myConfigurationPojo = methodConfPojo;
		} catch (Exception e) {
			setParametersEmpty();
		} 
		
	}
	
	private void setParametersEmpty() {
		myConfigurationPojo = new ConfigurationPojo("","","","","","");
	}
	
	public String getName() { return Constants.ACTION_SETUP_DEPARTMENTARIUM; }
	public String getId() { return Constants.ID_ACTION_SETUP_DEPARTMENTARIUM; }
	
	public String doSelection() { 
		isSelected = true;
		myUserJavaBean.setSelectedAction(this);
		return getId(); 
	}

	public boolean isSelected() { return isSelected; }
	
	private void reset() {
		isSelected = false;
		setFromPersistent();
	}
	
	public String getDptName() { return myConfigurationPojo.getDepartmentariumName(); }
	public String getDptHost() { return myConfigurationPojo.getDepartmentariumHost(); }
	public String getDptWebsiteName() { return myConfigurationPojo.getDepartmentariumWebsiteName(); }
	public String getDptWebServiceName() { return myConfigurationPojo.getDepartmentariumWebServiceName(); }
	public String getAtenariumUrl() { return myConfigurationPojo.getAtenariumUrl(); }
	public String getPrefix() { return myConfigurationPojo.getPrefix(); }
	
	public void setDptName(String aDptName) { myConfigurationPojo.setDepartmentariumName(aDptName); }
	public void setDptHost(String aDptHost) { myConfigurationPojo.setDepartmentariumHost(aDptHost); }
	public void setDptWebsiteName(String aDptWebsiteName) { myConfigurationPojo.setDepartmentariumWebsiteName(aDptWebsiteName); }
	public void setDptWebServiceName(String aDptWebServiceName) { myConfigurationPojo.setDepartmentariumWebServiceName(aDptWebServiceName); }
	public void setPrefix(String aPrefix) { myConfigurationPojo.setPrefix(aPrefix); }
	public void setAtenariumUrl(String aAtenariumUrl) { myConfigurationPojo.setAtenariumUrl(aAtenariumUrl); }

	public String getError() { return myError; }
	public void setError(Exception anException) { myError = anException.getMessage(); }
	
	public String doUnselection() {
		reset();
		return getId();
	}
	
		
	public String doAction() {
		String currentUsername = myUserJavaBean.getUsername();
		String currentPassword = myUserJavaBean.getPassword();
		try {
			myUserJavaBean.getDepartmentarium().configureDepartmentarium(currentUsername,currentPassword,myConfigurationPojo);
		} catch (Exception e) { 
			setError(e);
			return Constants.ACTION_NOT_DONE;
		}
		return Constants.ACTION_SETUP_DEPARTMENTARIUM_DONE;
	}

}
